@@ -256,7 +256,7 @@ void ung_amcmc::is_correction_psi(T model, const unsigned int nsim_states,
   double sum_w = 0.0;
   
 #ifdef _OPENMP
-#pragma omp parallel num_threads(n_threads) default(none) shared(Valpha, sum_w) firstprivate(model) 
+#pragma omp parallel num_threads(n_threads) default(shared) firstprivate(model) 
 {
   
   model.engine = sitmo::prng_engine(omp_get_thread_num() + 1);
@@ -405,7 +405,7 @@ void ung_amcmc::is_correction_bsf(T model, const unsigned int nsim_states,
   double sum_w = 0.0;
   
 #ifdef _OPENMP
-#pragma omp parallel num_threads(n_threads) default(none) shared(Valpha, sum_w) firstprivate(model) 
+#pragma omp parallel num_threads(n_threads) default(shared) firstprivate(model) 
 {
   
   model.engine = sitmo::prng_engine(omp_get_thread_num() + 1);
@@ -515,7 +515,7 @@ void ung_amcmc::is_correction_spdk(T model, const unsigned int nsim_states,
   double sum_w = 0.0;
   
 #ifdef _OPENMP
-#pragma omp parallel num_threads(n_threads) default(none) shared(Valpha, sum_w) firstprivate(model) 
+#pragma omp parallel num_threads(n_threads) default(shared) firstprivate(model) 
 {
   
   model.engine = sitmo::prng_engine(omp_get_thread_num() + 1);
@@ -640,7 +640,7 @@ template <class T>
 void ung_amcmc::approx_state_posterior(T model, const unsigned int n_threads) {
   
 #ifdef _OPENMP
-#pragma omp parallel num_threads(n_threads) default(none) firstprivate(model) 
+#pragma omp parallel num_threads(n_threads) default(shared) firstprivate(model) 
 {
   
   model.engine = sitmo::prng_engine(omp_get_thread_num() + 1);
